import createHttpError from "http-errors";
import express from "express";
import path from "path";
import cookieParser from "cookie-parser";
import logger from "morgan";

import indexRouter from "./routes/index";

if (!process.env.R_AWS_KEY) {
  console.log("FATAL: 'R_AWS_KEY' environment variable is not set");
  process.exit(-1);
}

if (!process.env.R_AWS_SECRET) {
  console.log("FATAL: 'R_AWS_SECRET' environment variable is not set");
  process.exit(-2);
}

const app = express().set("env", process.env.NODE_ENV || "production");

const errorHandler = (err, res) => {
  res.locals.message = err.message || "unknown error";
  res.locals.error = app.get("env") === "development" ? err : {};
  res.render("errors", {
    message: "An error occurred",
    error: { status: err.status || 500 },
  });
};

app.set("views", path.join(__dirname, "views"));
app.set("view engine", "pug");

app.use(logger("dev"));
app.use(express.json());
app.use(express.urlencoded({ extended: false }));
app.use(cookieParser());
app.use(express.static(path.join(__dirname, "public")));

app.use("/", indexRouter);

app.use((err, req, res, next) => {
  errorHandler(err, res);
});

app.use((_, res) => {
  errorHandler(createHttpError(404), res);
});

module.exports = app;
