import express from "express";
import { cleanOldItems, createDownloadLink, getBucketFiles } from "../api";

const PUBLIC_KEY = `-----BEGIN PUBLIC KEY-----
MIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAqXedleDOugdk9sBpgFOA
0+MogIbBF7+iXIIHv8CRBbrrf8nxLSgQvbHQIP0EklebDgLZRgyGI3SSQYj7D957
uNf1//dpkELNzfuezgAyFer9+iH4Svq46HADp5k+ugaK0mMDZM7OLOgo7415/+z4
NIQopv8prMFdxkShr4e4dpR+S6LYMYMVjsi1gnYWaZJMWgzeZouXFSscS1/XDXSE
vr1Jfqme+RmB4Q2QqGcDrY2ijumCJYJzQqlwG6liJ4FNg0U3POTCQDhQmuUoEJe0
/dyiWlo48WQbBu6gUDHbTCCUSZPs2Lc9l65MqOCpX76+VXPYetZgqpMF4GVzb2y9
kETxFNpiMYBlOBZk0I1G33wqVmw46MI5IZMQ2z2F8Mzt1hByUNTgup2IQELCv1a5
a2ACs2TBRuAy1REeHhjLgiA/MpoGX7TpoHCGyo8jBChJVpP9ZHltKoChwDC+bIyx
rgYH3jYDkl2FFuAUJ8zAZl8U1kjqZb9HGq9ootMk34Dbo3IVkc2azB2orEP9F8QV
KxvZZDA9FAFEthSiNf5soJ6mZGLi0es5EWPoKMUEd9tG5bP980DySAWSSRK0AOfE
QShT/z7oG79Orxyomwrb8ZJCi7wEfcCuK1NWgqLVUgXhpi2J9WYS6DAbF3Oh3Hhl
DYSHlcfFBteqNDlR2uFInIECAwEAAQ==
-----END PUBLIC KEY-----`;

const router = express.Router();
const stages = ["release", "nightly", "alpha", "beta", "RC"];

router.get("/", (_, res, next) => {
  try {
    res.render("index", {
      title: "Fifthgrid Builds",
      stages,
    });
  } catch (err) {
    next(err);
  }
});

router.get("/download", async (req, res, next) => {
  try {
    res.redirect(await createDownloadLink(req.query.key.toString()));
  } catch (err) {
    next(err);
  }
});

router.get("/stage", async (req, res, next) => {
  try {
    const name = req.query.name.toString();
    if (!stages.includes(name)) {
      res.render("errors", {
        message: "An error occurred",
        error: { status: 404 },
      });
      return;
    }

    const files = await getBucketFiles(name);
    res.render("stage", {
      title: "Fifthgrid Builds",
      name: name,
      public_key: PUBLIC_KEY,
      files: files,
    });
  } catch (err) {
    next(err);
  }
});

setInterval(
  async () => {
    try {
      for (const stage of stages) {
        try {
          await getBucketFiles(stage);
        } catch (e) {
          console.log(e);
        }
      }
      await cleanOldItems();
    } catch (e) {
      console.log(e);
    }
  },
  15 * 60 * 1000,
);

export default router;
